@@ -35,34 +35,34 @@ Root classes for adding custom functionality to the code.
 .. moduleauthor:: Yann Gordon <yann@tvb.invalid>
 """
 
-import os
-import json
-import uuid
-import psutil
-import numpy
 import importlib
-from functools import wraps
-from datetime import datetime
+import json
+import os
+import typing
+import uuid
 from abc import ABCMeta, abstractmethod
+from datetime import datetime
+from functools import wraps
+
+import numpy
+import psutil
 from six import add_metaclass
-from tvb.basic.profile import TvbProfile
 from tvb.basic.logger.builder import get_logger
-from tvb.basic.neotraits.api import HasTraits
+from tvb.basic.neotraits.api import Attr, HasTraits, List
+from tvb.basic.profile import TvbProfile
 from tvb.core.adapters import constants
-from tvb.core.entities.generic_attributes import GenericAttributes
-from tvb.core.entities.load import load_entity_by_gid
-from tvb.core.neocom import h5
-from tvb.core.neotraits.h5 import H5File
-from tvb.core.utils import date2string, LESS_COMPLEX_TIME_FORMAT
-from tvb.core.entities.storage import dao
-from tvb.core.entities.file.files_helper import FilesHelper
-from tvb.core.entities.transient.structure_entities import DataTypeMetaData
 from tvb.core.adapters.exceptions import IntrospectionException, LaunchException, InvalidParameterException
 from tvb.core.adapters.exceptions import NoMemoryAvailableException
-from tvb.core.neotraits.forms import Form, DataTypeSelectField, TraitDataTypeSelectField
-
-ATT_METHOD = "python_method"
-ATT_PARAMETERS = "parameters_prefix"
+from tvb.core.entities.file.files_helper import FilesHelper
+from tvb.core.entities.generic_attributes import GenericAttributes
+from tvb.core.entities.load import load_entity_by_gid
+from tvb.core.entities.storage import dao
+from tvb.core.entities.transient.structure_entities import DataTypeMetaData
+from tvb.core.neocom import h5
+from tvb.core.neotraits.forms import Form
+from tvb.core.neotraits.h5 import H5File
+from tvb.core.neotraits.view_model import DataTypeGidAttr, ViewModel
+from tvb.core.utils import date2string, LESS_COMPLEX_TIME_FORMAT
 
 LOGGER = get_logger("ABCAdapter")
 
@@ -121,19 +121,35 @@ def nan_allowed():
 class ABCAdapterForm(Form):
     @staticmethod
     def get_required_datatype():
+        """
+        Each Adapter's computation is based on a main Datatype. This method should keep the class of it.
+        This Datatype will be stored to DB at introspection time.
+        :return: DataType class
+        """
         raise NotImplementedError
 
-    # TODO: This keeps filters for the required_datatype. Only to be in DB at introspection?
     @staticmethod
     def get_filters():
+        """
+        Should keep filters for the required_datatype. These filters are stored in DB at introspection time.
+        :return: FilterChain
+        """
         raise NotImplementedError
 
     @staticmethod
     def get_input_name():
+        """
+        The Form's input name for the required_datatype. Will be stored in DB at introspection time.
+        :return: str
+        """
         raise NotImplementedError
 
     @staticmethod
     def get_view_model():
+        """
+        Should keep the ViewModel class that corresponds to the current Adapter.
+        :return: ViewModel class
+        """
         raise NotImplementedError
 
     def get_traited_datatype(self):
@@ -143,36 +159,12 @@ class ABCAdapterForm(Form):
         """
         return None
 
-    def _get_original_field_name(self, field):
-        start_idx = len(self.prefix) + 1 if (self.prefix != '') else 0
-        return field.name[start_idx:]
-
-    # TODO: Used to support original flow (pass form values as kwargs). Also for the asynchronous launch
-    def get_dict(self):
-        attrs_dict = {}
-        for field in self.fields:
-            attrs_dict.update({field.name: field.data})
-        attrs_dict.update({self.RANGE_1_NAME: self.range_1})
-        attrs_dict.update({self.RANGE_2_NAME: self.range_2})
-        return attrs_dict
-
     def fill_from_post_plus_defaults(self, form_data):
         self.fill_from_trait(self.get_view_model()())
         for field in self.fields:
             if field.name in form_data:
                 field.fill_from_post(form_data)
 
-    def get_form_values(self):
-        attrs_dict = {}
-        for field in self.fields:
-            field_name = self._get_original_field_name(field)
-            if isinstance(field, DataTypeSelectField) or isinstance(field, TraitDataTypeSelectField):
-                field_data = field.get_dt_from_db()
-            else:
-                field_data = field.data
-            attrs_dict.update({field_name: field_data})
-        return attrs_dict
-
 
 @add_metaclass(ABCMeta)
 class ABCAdapter(object):
@@ -187,7 +179,6 @@ class ABCAdapter(object):
     KEY_VALUE = constants.ATT_VALUE
     KEY_DEFAULT = constants.ATT_DEFAULT
     KEY_DATATYPE = "datatype"
-    KEY_DISABLED = "disabled"
     KEY_FILTERABLE = "filterable"
 
     # model.Algorithm instance that will be set for each adapter created by in build_adapter method
@@ -260,6 +251,15 @@ class ABCAdapter(object):
     def get_form_class(self):
         return None
 
+    def get_adapter_fragments(self, view_model):
+        """
+        The result will be used for introspecting and checking operation changed input
+        params from the defaults, to show in web gui.
+        :return: a list of ABCAdapterForm classes, in case the current Adapter GUI
+        will be composed of multiple sub-forms.
+        """
+        return {}
+
     def get_view_model_class(self):
         return self.get_form_class().get_view_model()
 
@@ -327,20 +327,16 @@ class ABCAdapter(object):
         else:
             self.generic_attributes.user_tag_2 = user_tag if user_tag is not None else perpetuated_identifier
 
-    @nan_not_allowed()
-    def _prelaunch(self, operation, uid=None, available_disk_space=0, view_model=None, **kwargs):
-        """
-        Method to wrap LAUNCH.
-        Will prepare data, and store results on return. 
-        """
+    def _extract_operation_data(self, operation):
         self.meta_data.update(json.loads(operation.meta_data))
-        self.storage_path = self.file_handler.get_project_folder(operation.project, str(operation.id))
+        operation = dao.get_operation_by_id(operation.id)
+        project = dao.get_project_by_id(operation.fk_launched_in)
+        self.storage_path = self.file_handler.get_project_folder(project, str(operation.id))
         self.operation_id = operation.id
         self.current_project_id = operation.project.id
         self.user_id = operation.fk_launched_by
 
-        self.configure(view_model)
-
+    def _ensure_enough_resources(self, available_disk_space, view_model):
         # Compare the amount of memory the current algorithms states it needs,
         # with the average between the RAM available on the OS and the free memory at the current moment.
         # We do not consider only the free memory, because some OSs are freeing late and on-demand only.
@@ -363,11 +359,29 @@ class ABCAdapter(object):
             msg = ("You only have %.2f GB of disk space available but the operation you "
                    "launched might require %.2f Stopping execution...")
             raise NoMemoryAvailableException(msg % (available_disk_space / 2 ** 20, required_disk_space / 2 ** 20))
+        return required_disk_space
 
+    def _update_operation_entity(self, operation, required_disk_space):
         operation.start_now()
         operation.estimated_disk_size = required_disk_space
         dao.store_entity(operation)
 
+    def fill_existing_indexes(self, operation, index_list):
+        self._extract_operation_data(operation)
+        self._prepare_generic_attributes()
+        return self._capture_operation_results(index_list)
+
+    @nan_not_allowed()
+    def _prelaunch(self, operation, uid=None, available_disk_space=0, view_model=None, **kwargs):
+        """
+        Method to wrap LAUNCH.
+        Will prepare data, and store results on return.
+        """
+        self._extract_operation_data(operation)
+        self.configure(view_model)
+        required_disk_size = self._ensure_enough_resources(available_disk_space, view_model)
+        self._update_operation_entity(operation, required_disk_size)
+
         self._prepare_generic_attributes(uid)
         result = self.launch(view_model)
 
@@ -412,6 +426,7 @@ class ABCAdapter(object):
                 with H5File.from_file(associated_file) as f:
                     f.store_generic_attributes(self.generic_attributes)
             dao.store_entity(res)
+            res.after_store()
             group_type = res.type
             count_stored += 1
 
@@ -452,6 +467,9 @@ class ABCAdapter(object):
         operation = dao.get_operation_by_id(self.operation_id)
         return operation.fk_operation_group is not None
 
+    def _get_output_path(self):
+        return self.storage_path
+
     @staticmethod
     def load_entity_by_gid(data_gid):
         """
@@ -463,21 +481,46 @@ class ABCAdapter(object):
 
     @staticmethod
     def load_traited_by_gid(data_gid):
-        # type: (uuid.UUID) -> HasTraits
+        # type: (typing.Union[uuid.UUID, str]) -> HasTraits
         """
         Load a generic HasTraits instance, specified by GID.
         """
-        index = load_entity_by_gid(data_gid.hex)
+        index = ABCAdapter.load_entity_by_gid(data_gid)
         return h5.load_from_index(index)
 
     @staticmethod
     def load_with_references(dt_gid):
-        # type: (uuid.UUID) -> HasTraits
-        dt_index = load_entity_by_gid(dt_gid)
+        # type: (typing.Union[uuid.UUID, str]) -> HasTraits
+        dt_index = ABCAdapter.load_entity_by_gid(dt_gid)
         h5_path = h5.path_for_stored_index(dt_index)
         dt, _ = h5.load_with_references(h5_path)
         return dt
 
+    def view_model_to_has_traits(self, view_model):
+        # type: (ViewModel) -> HasTraits
+        has_traits_class = view_model.linked_has_traits
+        has_traits = has_traits_class()
+        view_model_class = type(view_model)
+        if not has_traits_class:
+            raise Exception("There is no linked HasTraits for this ViewModel {}".format(type(view_model)))
+        for attr_name in has_traits_class.declarative_attrs:
+            view_model_class_attr = getattr(view_model_class, attr_name)
+            view_model_attr = getattr(view_model, attr_name)
+            if isinstance(view_model_class_attr, DataTypeGidAttr) and view_model_attr:
+                attr_value = self.load_with_references(view_model_attr)
+            elif isinstance(view_model_class_attr, Attr) and isinstance(view_model_attr, ViewModel):
+                attr_value = self.view_model_to_has_traits(view_model_attr)
+            elif isinstance(view_model_class_attr, List) and len(view_model_attr) > 0 and isinstance(view_model_attr[0],
+                                                                                                     ViewModel):
+                attr_value = list()
+                for view_model_elem in view_model_attr:
+                    elem = self.view_model_to_has_traits(view_model_elem)
+                    attr_value.append(elem)
+            else:
+                attr_value = view_model_attr
+            setattr(has_traits, attr_name, attr_value)
+        return has_traits
+
     @staticmethod
     def build_adapter_from_class(adapter_class):
         """
@@ -522,13 +565,10 @@ class ABCAdapter(object):
             LOGGER.exception(msg)
             raise IntrospectionException(msg)
 
-    def review_operation_inputs(self, parameters):
-        # TODO: implement this for neoforms
-        """
-        :returns: a list with the inputs from the parameters list that are instances of DataType,\
-            and a dictionary with all parameters which are different than the declared defauts
-        """
-        return {}, None
+    def load_view_model(self, operation):
+        storage_path = self.file_handler.get_project_folder(operation.project, str(operation.id))
+        input_gid = json.loads(operation.parameters)['gid']
+        return h5.load_view_model(input_gid, storage_path)
 
 
 @add_metaclass(ABCMeta)
