@@ -36,7 +36,6 @@ from datetime import datetime
 import numpy
 from tvb.core import utils
 from tvb.core.entities.file.files_helper import FilesHelper
-from tvb.core.entities.model.model_datatype import DataType
 from tvb.core.entities.storage import dao
 from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.neocom.h5 import REGISTRY
@@ -165,113 +164,6 @@ class SimpleFloatField(Field):
             self.data = float(self.unvalidated_data)
 
 
-class DataTypeSelectField(Field):
-    template = 'form_fields/datatype_select_field.html'
-    missing_value = 'explicit-None-value'
-
-    def __init__(self, datatype_index, form, name=None, disabled=False, required=False, label='', doc='',
-                 conditions=None, draw_dynamic_conditions_buttons=True, dynamic_conditions=None, has_all_option=False,
-                 show_only_all_option=False):
-        super(DataTypeSelectField, self).__init__(form, name, disabled, required, label, doc)
-        self.datatype_index = datatype_index
-        self.conditions = conditions
-        self.draw_dynamic_conditions_buttons = draw_dynamic_conditions_buttons
-        self.dynamic_conditions = dynamic_conditions
-        self.has_all_option = has_all_option
-        self.show_only_all_option = show_only_all_option
-
-    @property
-    def get_dynamic_filters(self):
-        return FilterChain().get_filters_for_type(self.datatype_index)
-
-    def _get_values_from_db(self):
-        all_conditions = FilterChain()
-        all_conditions += self.conditions
-        all_conditions += self.dynamic_conditions
-        filtered_datatypes, count = dao.get_values_of_datatype(self.owner.project_id,
-                                                               self.datatype_index,
-                                                               all_conditions)
-        return filtered_datatypes
-
-    def options(self):
-        if not self.owner.project_id:
-            raise ValueError('A project_id is required in order to query the DB')
-
-        filtered_datatypes = self._get_values_from_db()
-
-        if not self.required:
-            choice = None
-            yield Option(
-                id='{}_{}'.format(self.name, None),
-                value=self.missing_value,
-                label=str(choice).title(),
-                checked=self.data is None
-            )
-
-        if not self.show_only_all_option:
-            for i, datatype in enumerate(filtered_datatypes):
-                yield Option(
-                    id='{}_{}'.format(self.name, i),
-                    value=datatype[2],
-                    label=self._prepare_display_name(datatype),
-                    checked=self.data == datatype[2]
-                )
-
-        if self.has_all_option:
-            if not self.owner.draw_ranges:
-                raise ValueError("The owner form should draw ranges inputs in order to support 'All' option")
-
-            all_values = ''
-            for fdt in filtered_datatypes:
-                all_values += str(fdt[2]) + ','
-
-            choice = "All"
-            yield Option(
-                id='{}_{}'.format(self.name, choice),
-                value=all_values[:-1],
-                label=choice,
-                checked=self.data is choice
-            )
-
-    def get_dt_from_db(self):
-        return dao.get_datatype_by_gid(self.data)
-
-    def _prepare_display_name(self, value):
-        # TODO remove duplicate with TraitedDataTypeSelectField
-        """
-        Populate meta-data fields for data_list (list of DataTypes).
-
-        Private method, to be called recursively.
-        It will receive a list of Attributes, and it will populate 'options'
-        entry with data references from DB.
-        """
-        # Here we only populate with DB data, actual
-        # XML check will be done after select and submit.
-        entity_gid = value[2]
-        actual_entity = dao.get_generic_entity(self.datatype_index, entity_gid, "gid")
-        display_name = actual_entity[0].display_name
-        display_name += ' - ' + (value[3] or "None ")
-        if value[5]:
-            display_name += ' - From: ' + str(value[5])
-        else:
-            display_name += utils.date2string(value[4])
-        if value[6]:
-            display_name += ' - ' + str(value[6])
-        display_name += ' - ID:' + str(value[0])
-
-        return display_name
-
-    def _from_post(self):
-        if self.unvalidated_data == self.missing_value:
-            self.unvalidated_data = None
-
-        if self.required and not self.unvalidated_data:
-            raise ValueError('Field required')
-
-        # TODO: ensure is in choices
-        self.data = self.unvalidated_data
-
-
 class TraitField(Field):
     # mhtodo: while this is consistent with the h5 api, it has the same problem
     #         it couples the system to traited attr declarations
@@ -340,7 +232,7 @@ class TraitDataTypeSelectField(TraitField):
     missing_value = 'explicit-None-value'
 
     def __init__(self, trait_attribute, form, name=None, conditions=None, draw_dynamic_conditions_buttons=True,
-                 dynamic_conditions=None, has_all_option=False):
+                 dynamic_conditions=None, has_all_option=False, show_only_all_option=False):
         super(TraitDataTypeSelectField, self).__init__(trait_attribute, form, name)
         if issubclass(type(trait_attribute), DataTypeGidAttr):
             type_to_query = trait_attribute.linked_datatype
@@ -355,10 +247,13 @@ class TraitDataTypeSelectField(TraitField):
         self.draw_dynamic_conditions_buttons = draw_dynamic_conditions_buttons
         self.dynamic_conditions = dynamic_conditions
         self.has_all_option = has_all_option
+        self.show_only_all_option = show_only_all_option
 
     def from_trait(self, trait, f_name):
         if hasattr(trait, f_name):
             self.data = getattr(trait, f_name)
+            if isinstance(self.data, uuid.UUID):
+                self.data = self.data.hex
 
     @property
     def get_dynamic_filters(self):
@@ -388,13 +283,14 @@ class TraitDataTypeSelectField(TraitField):
                 checked=self.data is None
             )
 
-        for i, datatype in enumerate(filtered_datatypes):
-            yield Option(
-                id='{}_{}'.format(self.name, i),
-                value=datatype[2],
-                label=self._prepare_display_name(datatype),
-                checked=self.data == datatype[2]
-            )
+        if not self.show_only_all_option:
+            for i, datatype in enumerate(filtered_datatypes):
+                yield Option(
+                    id='{}_{}'.format(self.name, i),
+                    value=datatype[2],
+                    label=self._prepare_display_name(datatype),
+                    checked=self.data == datatype[2]
+                )
 
         if self.has_all_option:
             if not self.owner.draw_ranges:
@@ -428,7 +324,7 @@ class TraitDataTypeSelectField(TraitField):
         entity_gid = value[2]
         actual_entity = dao.get_generic_entity(self.datatype_index, entity_gid, "gid")
         display_name = actual_entity[0].display_name
-        display_name += ' - ' + (value[3] or "None ")   # Subject
+        display_name += ' - ' + (value[3] or "None ")  # Subject
         if value[5]:
             display_name += ' - From: ' + str(value[5])
         else:
@@ -791,4 +687,4 @@ class Form(object):
     def fill_from_single_post_param(self, **param):
         param_key = list(param)[0]
         field = getattr(self, param_key)
-        field.fill_from_post(param)
\ No newline at end of file
+        field.fill_from_post(param)
